@@ -1,5 +1,5 @@
 /* path-concat.c -- concatenate two arbitrary pathnames
-   Copyright (C) 1996, 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
+   Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -55,14 +55,7 @@ char *malloc ();
 char *strdup ();
 #endif
 
-#ifndef DIRECTORY_SEPARATOR
-# define DIRECTORY_SEPARATOR '/'
-#endif
-
-#ifndef ISSLASH
-# define ISSLASH(C) ((C) == DIRECTORY_SEPARATOR)
-#endif
-
+#include "dirname.h"
 #include "xalloc.h"
 #include "path-concat.h"
 
@@ -84,8 +77,8 @@ path_concat (const char *dir, const char *base, char **base_in_result)
 {
   char *p;
   char *p_concat;
-  size_t base_len;
-  size_t dir_len;
+  size_t baselen;
+  size_t dirlen;
 
   if (!dir)
     {
@@ -96,27 +89,28 @@ path_concat (const char *dir, const char *base, char **base_in_result)
     }
 
   /* DIR is not empty. */
-  base_len = strlen (base);
-  dir_len = strlen (dir);
+  baselen = base_len (base);
+  dirlen = strlen (dir);
 
-  p_concat = malloc (dir_len + base_len + 2);
+  p_concat = malloc (dirlen + baselen + 2);
   if (!p_concat)
     return 0;
 
-  p = mempcpy (p_concat, dir, dir_len);
+  p = mempcpy (p_concat, dir, dirlen);
 
-  if (dir_len > 0)
+  if (FILESYSTEM_PREFIX_LEN (dir) < dirlen)
     {
-      if (ISSLASH (*(p - 1)) && ISSLASH(*base))
+      if (ISSLASH (*(p - 1)) && ISSLASH (*base))
 	--p;
-      else if (!ISSLASH (*(p - 1)) && !ISSLASH(*base))
+      else if (!ISSLASH (*(p - 1)) && !ISSLASH (*base))
 	*p++ = DIRECTORY_SEPARATOR;
     }
 
   if (base_in_result)
     *base_in_result = p;
 
-  memcpy (p, base, base_len + 1);
+  memcpy (p, base, baselen);
+  p[baselen] = '\0';
 
   return p_concat;
 }
